@@ -184,7 +184,7 @@ class SO3(SMPose):
         :param unit: angular units: 'rad' [default], or 'deg'
         :type unit: str
         :return: 3-vector of Euler angles
-        :rtype: numpy.ndarray, shape=(3,)
+        :rtype: ndarray(3,), ndarray(n,3)
 
         ``x.eul`` is the Euler angle representation of the rotation.  Euler angles are
         a 3-vector :math:`(\phi, \theta, \psi)` which correspond to consecutive
@@ -193,7 +193,7 @@ class SO3(SMPose):
         If ``len(x)`` is:
 
         - 1, return an ndarray with shape=(3,)
-        - N>1, return ndarray with shape=(N,3)
+        - N>1, return ndarray with shape=(3,N)
 
         :seealso: :func:`~spatialmath.pose3d.SE3.Eul`, :func:`~spatialmath.base.transforms3d.tr2eul`
         :SymPy: not supported
@@ -201,7 +201,7 @@ class SO3(SMPose):
         if len(self) == 1:
             return base.tr2eul(self.A, unit=unit)
         else:
-            return np.array([base.tr2eul(x, unit=unit) for x in self.A]).T
+            return np.array([base.tr2eul(x, unit=unit) for x in self.A])
 
     def rpy(self, unit='rad', order='zyx'):
         """
@@ -212,7 +212,7 @@ class SO3(SMPose):
         :param unit: angular units: 'rad' [default], or 'deg'
         :type unit: str
         :return: 3-vector of roll-pitch-yaw angles
-        :rtype: numpy.ndarray, shape=(3,)
+        :rtype: ndarray(3,), ndarray(n,3)
 
         ``x.rpy`` is the roll-pitch-yaw angle representation of the rotation.  The angles are
         a 3-vector :math:`(r, p, y)` which correspond to successive rotations about the axes
@@ -231,7 +231,7 @@ class SO3(SMPose):
         If `len(x)` is:
 
         - 1, return an ndarray with shape=(3,)
-        - N>1, return ndarray with shape=(N,3)
+        - N>1, return ndarray with shape=(3,N)
 
         :seealso: :func:`~spatialmath.pose3d.SE3.RPY`, :func:`~spatialmath.base.transforms3d.tr2rpy`
         :SymPy: not supported
@@ -239,7 +239,7 @@ class SO3(SMPose):
         if len(self) == 1:
             return base.tr2rpy(self.A, unit=unit, order=order)
         else:
-            return np.array([base.tr2rpy(x, unit=unit, order=order) for x in self.A]).T
+            return np.array([base.tr2rpy(x, unit=unit, order=order) for x in self.A])
 
     def angvec(self, unit='rad'):
         r"""
@@ -408,7 +408,7 @@ class SO3(SMPose):
         return cls([base.q2r(base.rand()) for _ in range(0, N)], check=False)
 
     @classmethod
-    def Eul(cls, angles, *, unit='rad'):
+    def Eul(cls, *angles, unit='rad'):
         r"""
         Construct a new SO(3) from Euler angles
 
@@ -419,26 +419,41 @@ class SO3(SMPose):
         :return: SO(3) rotation
         :rtype: SO3 instance
 
-        ``SO3.Eul(𝚪)`` is an SO(3) rotation defined by a 3-vector of Euler angles :math:`\Gamma = (\phi, \theta, \psi)` which
-        correspond to consecutive rotations about the Z, Y, Z axes respectively.
+        ``SO3.Eul(𝚪)`` is an SO(3) rotation defined by a 3-vector of Euler
+          angles :math:`\Gamma = (\phi, \theta, \psi)` which correspond to
+          consecutive rotations about the Z, Y, Z axes respectively. If ``𝚪``
+          is an Nx3 matrix then the result is a sequence of rotations each
+          defined by Euler angles corresponding to the rows of ``angles``.
 
-        If ``𝚪`` is an Nx3 matrix then the result is a sequence of rotations each defined by Euler angles
-        corresponding to the rows of ``angles``.
+        ``SO3.Eul(φ, θ, ψ)`` as above but the angles are provided as three
+          scalars.
+
+        Example:
+
+        .. runblock:: pycon
+        
+            >>> from spatialmath import SO3
+            >>> SO3.Eul(0.1, 0.2, 0.3)
+            >>> SO3.Eul([0.1, 0.2, 0.3])
+            >>> SO3.Eul(10, 20, 30, 'deg')
 
         :seealso: :func:`~spatialmath.pose3d.SE3.eul`, :func:`~spatialmath.pose3d.SE3.Eul`, :func:`~spatialmath.base.transforms3d.eul2r`
         """
+        if len(angles) == 1:
+            angles = angles[0]
+
         if base.isvector(angles, 3):
             return cls(base.eul2r(angles, unit=unit), check=False)
         else:
             return cls([base.eul2r(a, unit=unit) for a in angles], check=False)
 
     @classmethod
-    def RPY(cls, angles, *, order='zyx', unit='rad'):
+    def RPY(cls, *angles, unit='rad', order='zyx', ):
         r"""
         Construct a new SO(3) from roll-pitch-yaw angles
 
         :param angles: roll-pitch-yaw angles
-        :type angles: array_like or numpy.ndarray with shape=(N,3)
+        :type angles: array_like(3), array_like(n,3)
         :param unit: angular units: 'rad' [default], or 'deg'
         :type unit: str
         :param order: rotation order: 'zyx' [default], 'xyz', or 'yxz'
@@ -446,8 +461,12 @@ class SO3(SMPose):
         :return: SO(3) rotation
         :rtype: SO3 instance
 
-        ``SO3.RPY(angles)`` is an SO(3) rotation defined by a 3-vector of roll, pitch, yaw angles :math:`(r, p, y)`
-          which correspond to successive rotations about the axes specified by ``order``:
+        - ``SO3.RPY(angles)`` is an SO(3) rotation defined by a 3-vector of
+          roll, pitch, yaw angles :math:`(\alpha, \beta, \gamma)`. If ``angles``
+          is an Nx3 matrix then the result is a sequence of rotations each
+          defined by RPY angles corresponding to the rows of angles. The angles
+          correspond to successive rotations about the axes specified by
+          ``order``:
 
              - ``'zyx'`` [default], rotate by yaw about the z-axis, then by pitch about the new y-axis,
                then by roll about the new x-axis.  Convention for a mobile robot with x-axis forward
@@ -459,15 +478,32 @@ class SO3(SMPose):
               then by roll about the new z-axis. Convention for a camera with z-axis parallel
               to the optic axis and x-axis parallel to the pixel rows.
 
-        If ``angles`` is an Nx3 matrix then the result is a sequence of rotations each defined by RPY angles
-        corresponding to the rows of angles.
+        - ``SO3.RPY(⍺, β, 𝛾)`` as above but the angles are provided as three
+          scalars.
+
+        Example:
+
+        .. runblock:: pycon
+        
+            >>> from spatialmath import SO3
+            >>> SO3.RPY(0.1, 0.2, 0.3)
+            >>> SO3.RPY([0.1, 0.2, 0.3])
+            >>> SO3.RPY(0.1, 0.2, 0.3, order='xyz')
+            >>> SO3.RPY(10, 20, 30, 'deg')
+
 
         :seealso: :func:`~spatialmath.pose3d.SE3.rpy`, :func:`~spatialmath.pose3d.SE3.RPY`, :func:`spatialmath.base.transforms3d.rpy2r`
         """
+        if len(angles) == 1:
+            angles = angles[0]
+
+        # angles = base.getmatrix(angles, (None, 3))
+        # return cls(base.rpy2r(angles, order=order, unit=unit), check=False)
+
         if base.isvector(angles, 3):
-            return cls(base.rpy2r(angles, order=order, unit=unit), check=False)
+            return cls(base.rpy2r(angles, unit=unit, order=order), check=False)
         else:
-            return cls([base.rpy2r(a, order=order, unit=unit) for a in angles], check=False)
+            return cls([base.rpy2r(a, unit=unit, order=order) for a in angles], check=False)
 
     @classmethod
     def OA(cls, o, a):
@@ -783,33 +819,33 @@ class SE3(SO3):
         :seealso: SE3.jacob, Twist.ad, :func:`~spatialmath.base.tr2jac`
         :SymPy: supported
         """
-        return base.adjoint(self.A)
+        return base.tr2adjoint(self.A)
 
     def jacob(self):
         """
-        Velocity transform for Se(3)
+        Velocity transform for SE(3)
 
         :return: Jacobian matrix
         :rtype: numpy.ndarray, shape=(6,6)
 
-        ``SEO.jacob`` is the 6x6 adjoint matrix
-
-        If spatial velocity :math:`\nu = (v_x, v_y, v_z, \omega_x, \omega_y, \omega_z)^T`
-        and the SE(3) represents the pose of {B} relative to {A}, 
-        ie. :math:`{}^A {\bf T}_B, and the adjoint is :math:`\mathbf{A}` then
-        :math:`{}^{A}\!\nu = \mathbf{A} {}^{B}\!\nu`.
+        ``SE3.jacob()`` is the 6x6 Jacobian that maps spatial velocity or
+        differential motion from frame {B} to frame {A} where the pose of {B}
+        relative to {A} is represented by the homogeneous transform T =
+        :math:`{}^A {\bf T}_B`.  
+        
+        .. note::
+            - To map from frame {A} to frame {B} use the transpose of this matrix.
+            - Use this method to map velocities between the robot end-effector frame
+              and the base frames.
 
         .. warning:: Do not use this method to map velocities between two frames
             on the same rigid-body.
-            
-        .. note:: Use this method to map velocities between robot base and
-            end-effector frames, rather than ``Ad()``.
 
         :seealso: SE3.Ad, Twist.ad, :func:`~spatialmath.base.tr2jac`
         :Reference: Robotics, Vision & Control: Second Edition, P. Corke, Springer 2016; p65.
         :SymPy: supported
         """
-        return tr2jac(self.A, samebody=False)
+        return base.tr2jac(self.A)
 
     def Twist3(self):
         """
@@ -997,7 +1033,7 @@ class SE3(SO3):
         return cls([base.transl(x, y, z) @ base.r2t(r.A) for (x, y, z, r) in zip(X, Y, Z, R)], check=False)
 
     @classmethod
-    def Eul(cls, angles, *, unit='rad'):
+    def Eul(cls, *angles, unit='rad'):
         r"""
         Create an SE(3) pure rotation from Euler angles
 
@@ -1008,24 +1044,38 @@ class SE3(SO3):
         :return: SE(3) matrix
         :rtype: SE3 instance
 
-        ``SE3.Eul(𝚪)`` is an SE(3) rotation defined by a 3-vector of Euler
-        angles :math:`\Gamma=(\phi, \theta, \psi)` which correspond to consecutive
-        rotations about the Z, Y, Z axes respectively.
+        - ``SE3.Eul(𝚪)`` is an SE(3) rotation defined by a 3-vector of Euler
+          angles :math:`\Gamma=(\phi, \theta, \psi)` which correspond to
+          consecutive rotations about the Z, Y, Z axes respectively.
 
         If ``𝚪`` is an Nx3 matrix then the result is a sequence of
         rotations each defined by Euler angles corresponding to the rows of
         ``𝚪``.
 
+        - ``SE3.Eul(φ, θ, ψ)`` as above but the angles are provided as three
+          scalars.
+
+        Example:
+
+        .. runblock:: pycon
+        
+            >>> from spatialmath import SE3
+            >>> SE3.Eul(0.1, 0.2, 0.3)
+            >>> SE3.Eul([0.1, 0.2, 0.3])
+            >>> SE3.Eul(10, 20, 30, unit='deg')
+
         :seealso: :func:`~spatialmath.pose3d.SE3.eul`, :func:`~spatialmath.base.transforms3d.eul2r`
         :SymPy: supported
         """
+        if len(angles) == 1:
+            angles = angles[0]
         if base.isvector(angles, 3):
             return cls(base.eul2tr(angles, unit=unit), check=False)
         else:
             return cls([base.eul2tr(a, unit=unit) for a in angles], check=False)
 
     @classmethod
-    def RPY(cls, angles, *, order='zyx', unit='rad'):
+    def RPY(cls, *angles, unit='rad', order='zyx'):
         r"""
         Create an SE(3) pure rotation from roll-pitch-yaw angles
 
@@ -1038,9 +1088,9 @@ class SE3(SO3):
         :return: SE(3) matrix
         :rtype: SE3 instance
 
-        ``SE3.RPY(𝚪)`` is an SE(3) rotation defined by a 3-vector of roll,
-        pitch, yaw angles :math:`\Gamma=(r, p, y)` which correspond to
-        successive rotations about the axes specified by ``order``:
+        - ``SE3.RPY(𝚪)`` is an SE(3) rotation defined by a 3-vector of roll,
+          pitch, yaw angles :math:`\Gamma=(r, p, y)` which correspond to
+          successive rotations about the axes specified by ``order``:
 
             - ``'zyx'`` [default], rotate by yaw about the z-axis, then by pitch about the new y-axis,
               then by roll about the new x-axis.  This is the **convention** for a mobile robot with x-axis forward
@@ -1055,9 +1105,25 @@ class SE3(SO3):
         If ``𝚪`` is an Nx3 matrix then the result is a sequence of rotations each defined by RPY angles
         corresponding to the rows of ``𝚪``.
 
+        - ``SE3.RPY(⍺, β, 𝛾)`` as above but the angles are provided as three
+          scalars.
+
+        Example:
+
+        .. runblock:: pycon
+        
+            >>> from spatialmath import SE3
+            >>> SE3.RPY(0.1, 0.2, 0.3)
+            >>> SE3.RPY([0.1, 0.2, 0.3])
+            >>> SE3.RPY(0.1, 0.2, 0.3, order='xyz')
+            >>> SE3.RPY(10, 20, 30, unit='deg')
+
         :seealso: :func:`~spatialmath.pose3d.SE3.rpy`, :func:`~spatialmath.base.transforms3d.rpy2r`
         :SymPy: supported
         """
+        if len(angles) == 1:
+            angles = angles[0]
+
         if base.isvector(angles, 3):
             return cls(base.rpy2tr(angles, order=order, unit=unit), check=False)
         else:
@@ -1310,19 +1376,27 @@ class SE3(SO3):
         return cls([base.transl(0, 0, _z) for _z in base.getvector(z)], check=False)
 
     @classmethod
-    def SO3(cls, R, check=True):
+    def SO3(cls, R, t=None, check=True):
         if isinstance(R, SO3):
             R = R.A
         elif base.isrot(R, check=check):
             pass
         else:
             raise ValueError('expecting SO3 or rotation matrix')
-        return cls(base.r2t(R))
+        if t is None:
+            return cls(base.r2t(R))
+        else:
+            return cls(base.rt2tr(R, t))
 
 if __name__ == '__main__':   # pragma: no cover
 
     import pathlib
 
+    a = SO3.RPY([.1, .2, .3])
+    print(a)
+    a = SO3.RPY(.1, .2, .3)
+    print(a)
+
     SE3._bgcolor = 'yellow'
     # SE3._format = '{:< 6.2f}'
     SE3._supress_small = False
