@@ -361,27 +361,86 @@ class SMPose(SMUserList):
         else:
             return log
 
-    def interp(self, s=None, start=None):
+    def interp(self, end=None, s=None):
+        """
+        Interpolate between poses (superclass method)
+
+        :param end: final pose
+        :type end: same as ``self``
+        :param s: interpolation coefficient, range 0 to 1, or number of steps
+        :type s: array_like or int
+        :return: interpolated pose
+        :rtype: same as ``self``
+
+        - ``X.interp(Y, s)`` interpolates pose between X between when s=0
+          and Y when s=1.
+        - ``X.interp(Y, N)`` interpolates pose between X and Y in ``N`` steps.
+
+        Example:
+
+        .. runblock:: pycon
+
+            >>> x = SE3(-1, -2, 0) * SE3.Rx(-0.3)
+            >>> y = SE3(1, 2, 0) * SE3.Rx(0.3)
+            >>> x.interp(y, 0)    # this is x
+            >>> x.interp(y, 1)    # this is y
+            >>> x.interp(y, 0.5)  # this is in between
+            >>> z = x.interp(y, 11)  # in 11 steps
+            >>> len(z)
+            >>> z[0]              # this is x
+            >>> z[5]              # this is in between
+
+        .. note::
+
+            - For SO3 and SE3 rotation is interpolated using quaternion spherical linear interpolation (slerp).
+            - Values of ``s`` outside the range [0,1] are silently clipped
+        :seealso: :func:`interp1`, :func:`~spatialmath.base.transforms3d.trinterp`, :func:`~spatialmath.base.quaternions.slerp`, :func:`~spatialmath.base.transforms2d.trinterp2`
+
+        :SymPy: not supported
+        """
+
+        if isinstance(s, int) and s > 1:
+            s = np.linspace(0, 1, s)
+        else:
+            s = base.getvector(s)
+            s = np.clip(s, 0, 1)
+
+        if len(self) > 1: 
+            raise ValueError('start pose must be a singleton')
+
+        if end is not None:
+            if len(end) > 1: 
+                raise ValueError('end pose must be a singleton')
+            end = end.A
+
+        if self.N == 2:
+            # SO(2) or SE(2)
+            return self.__class__([base.trinterp2(start=self.A, end=end, s=_s) for _s in s])
+
+        elif self.N == 3:
+            # SO(3) or SE(3)
+            return self.__class__([base.trinterp(start=self.A, end=end, s=_s) for _s in s])
+
+    def interp1(self, s=None):
         """
         Interpolate pose (superclass method)
 
-        :param start: initial pose
-        :type start: same as ``self``
+        :param end: final pose
+        :type end: same as ``self``
         :param s: interpolation coefficient, range 0 to 1
-        :type s: float or array_like
+        :type s: array_like
         :return: interpolated pose
         :rtype: SO2, SE2, SO3, SE3 instance
 
-        - ``X.interp(s)`` interpolates the pose X between identity when s=0
-          and X when s=1.
+        - ``X.interp(s)`` interpolates pose between identity when s=0, and X when s=1.
 
-         ======  ======  ===========  ===============================
-         len(X)  len(s)  len(result)  Result
-         ======  ======  ===========  ===============================
-         1       1       1            Y = interp(identity, X, s)
-         M       1       M            Y[i] = interp(T0, X[i], s)
-         1       M       M            Y[i] = interp(T0, X, s[i])
-         ======  ======  ===========  ===============================
+            ======  ======  ===========  ===============================
+            len(X)  len(s)  len(result)  Result
+            ======  ======  ===========  ===============================
+            1       1       1            Y = interp(X, s)
+            M       1       M            Y[i] = interp(X[i], s)
+            1       M       M            Y[i] = interp(X, s[i])
+            ======  ======  ===========  ===============================
 
         Example::
 
@@ -409,11 +468,13 @@ class SMPose(SMUserList):
 
         #. For SO3 and SE3 rotation is interpolated using quaternion spherical linear interpolation (slerp).
 
-        :seealso: :func:`~spatialmath.base.transforms3d.trinterp`, :func:`~spatialmath.base.quaternions.slerp`, :func:`~spatialmath.base.transforms2d.trinterp2`
+        :seealso: :func:`interp`, :func:`~spatialmath.base.transforms3d.trinterp`, :func:`~spatialmath.base.quaternions.slerp`, :func:`~spatialmath.base.transforms2d.trinterp2`
 
         :SymPy: not supported
         """
         s = base.getvector(s)
+        s = np.clip(s, 0, 1)
+
         if start is not None:
             assert len(start) == 1, 'len(start) must == 1'
             start = start.A
@@ -432,7 +493,6 @@ class SMPose(SMUserList):
                 return self.__class__([base.trinterp(start, self.A, s=_s) for _s in s])
             else:
                 return self.__class__([base.trinterp(start, x, s=s[0]) for x in self.data])
-
     def norm(self):
         """
         Normalize pose (superclass method)
@@ -649,7 +709,7 @@ class SMPose(SMUserList):
         if self._ansiformatter is None:
             self._ansiformatter = ANSIMatrix(style='thick')
 
-        return self._ansiformatter.str(self.A)
+        return "\n".join([self._ansiformatter.str(A) for A in self.data])
 
     def _string_color(self, color=False):
         """
@@ -796,10 +856,19 @@ class SMPose(SMUserList):
         """
         if start is not None:
             start = start.A
-        if self.N == 2:
-            base.tranimate2(self.A, start=start, *args, **kwargs)
+        
+        if len(self) > 1:
+            # trajectory case
+            if self.N == 2:
+                base.tranimate2(self.data, *args, **kwargs)
+            else:
+                base.tranimate(self.data, *args, **kwargs)
         else:
-            base.tranimate(self.A, start=start, *args, **kwargs)
+            # singleton case
+            if self.N == 2:
+                base.tranimate2(self.A, start=start, *args, **kwargs)
+            else:
+                base.tranimate(self.A, start=start, *args, **kwargs)
 
 
 # ------------------------------------------------------------------------ #
@@ -997,6 +1066,30 @@ class SMPose(SMUserList):
         else:
             return NotImplemented
 
+    def __matmul__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
+        """
+        Overloaded ``@`` operator (superclass method)
+
+        :return: Product of two operands with normalization
+        :rtype: Pose instance or NumPy array
+        :raises ValueError: for incompatible arguments
+
+        - ``X @ Y`` compounds the poses ``X`` and ``Y`` and normalizes the result
+        - ``X @= Y`` compounds the poses ``X`` and ``Y``, normalizes the result,
+          and places the result in ``X``
+
+        .. note:: This operator is functionally equivalent to ``*`` but is more
+            costly.  It is useful for cases where a pose is incrementally 
+            update over many cycles.
+
+        :seealso: :func:`__mul__`, :func:`~spatialmath.base.trnorm`
+        """
+        if isinstance(left, right.__class__):
+            #print('*: pose x pose')
+            return left.__class__(left._op2(right, lambda x, y: base.trnorm(x @ y)), check=False)
+        else:
+            raise TypeError('@ only applies to pose composition')
+
     def __rmul__(right, left):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
         Overloaded ``*`` operator (superclass method)
